Let me crawl
=======================

Curate proxies from various sources in terms of latency.

.. code-block:: bash

    >> from letmecrawl import LMC
    >> for proxy in LMC().pop():
    >>     print proxy
    88.99.11.10:6666



Installation
-----------------
.. code-block:: bash

    pip install letmecrawl
